import { Dialog } from '@jupyterlab/apputils';
export declare const KFP_SCHEMA = "kfp";
export declare const RUNTIMES_SCHEMASPACE = "runtimes";
export declare const RUNTIME_IMAGES_SCHEMASPACE = "runtime-images";
export declare const COMPONENT_CATALOGS_SCHEMASPACE = "component-catalogs";
export interface IRuntime {
    name: string;
    display_name: string;
    schema_name: string;
    metadata: {
        runtime_type: string;
    };
}
export interface ISchema {
    name: string;
    title: string;
    runtime_type: string;
}
export interface IRuntimeType {
    id: string;
    display_name: string;
    icon: string;
    export_file_types: {
        id: string;
        display_name: string;
    }[];
}
export declare class PipelineService {
    /**
     * Returns a list of resources corresponding to each active runtime-type.
     */
    static getRuntimeTypes(): Promise<IRuntimeType[]>;
    /**
     * Returns a list of external runtime configurations available as
     * `runtimes metadata`. This is used to submit the pipeline to be
     * executed on these runtimes.
     */
    static getRuntimes(): Promise<any>;
    /**
     * Returns a list of runtime schema
     */
    static getRuntimesSchema(showError?: boolean): Promise<any>;
    /**
     * Return a list of configured docker images that are used as runtimes environments
     * to run the pipeline nodes.
     */
    static getRuntimeImages(): Promise<any>;
    /**
     * Creates a Dialog for passing to makeServerRequest
     */
    static getWaitDialog(title?: string, body?: string): Dialog<any>;
    /**
     * Submit the pipeline to be executed on an external runtime (e.g. Kbeflow Pipelines)
     *
     * @param pipeline
     * @param runtimeName
     */
    static submitPipeline(pipeline: any, runtimeName: string): Promise<any>;
    /**
     * Export a pipeline to different formats (e.g. DSL, YAML, etc). These formats
     * are understood by a given runtime.
     *
     * @param pipeline
     * @param pipeline_export_format
     * @param pipeline_export_path
     * @param overwrite
     */
    static exportPipeline(pipeline: any, pipeline_export_format: string, pipeline_export_path: string, overwrite: boolean): Promise<any>;
    static getNodeType(filepath: string): string;
    /**
     * Check if a given file is allowed to be added to the pipeline
     * @param item
     */
    static isSupportedNode(file: any): boolean;
    static getPipelineRelativeNodePath(pipelinePath: string, nodePath: string): string;
    static getWorkspaceRelativeNodePath(pipelinePath: string, nodePath: string): string;
    static setNodePathsRelativeToWorkspace(pipeline: any, pipelinePath: string): any;
}
