"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SubmitFileButtonExtension = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
/*
 * Copyright 2018-2022 Elyra Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
const services_1 = require("@elyra/services");
const ui_components_1 = require("@elyra/ui-components");
const apputils_1 = require("@jupyterlab/apputils");
const coreutils_1 = require("@jupyterlab/coreutils");
const FileSubmissionDialog_1 = require("./FileSubmissionDialog");
const formDialogWidget_1 = require("./formDialogWidget");
const PipelineService_1 = require("./PipelineService");
const runtime_utils_1 = require("./runtime-utils");
const utils_1 = __importDefault(require("./utils"));
/**
 * Submit notebook button extension
 *  - Attach button to notebook toolbar and launch a dialog requesting
 *  information about the remote location to where submit the notebook
 *  for execution
 */
class SubmitFileButtonExtension {
    constructor() {
        this.showWidget = (document) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            const { context } = document;
            if (context.model.dirty) {
                const dialogResult = yield apputils_1.showDialog({
                    title: 'This notebook contains unsaved changes. To run the notebook as pipeline the changes need to be saved.',
                    buttons: [
                        apputils_1.Dialog.cancelButton(),
                        apputils_1.Dialog.okButton({ label: 'Save and Submit' })
                    ]
                });
                if (dialogResult.button.accept === false) {
                    return;
                }
                yield context.save();
            }
            const env = yield services_1.ContentParser.getEnvVars(context.path).catch(error => ui_components_1.RequestErrors.serverError(error));
            const runtimes = yield PipelineService_1.PipelineService.getRuntimes().catch(error => ui_components_1.RequestErrors.serverError(error));
            const images = yield PipelineService_1.PipelineService.getRuntimeImages().catch(error => ui_components_1.RequestErrors.serverError(error));
            const schema = yield PipelineService_1.PipelineService.getRuntimesSchema().catch(error => ui_components_1.RequestErrors.serverError(error));
            const runtimeData = runtime_utils_1.createRuntimeData({ schema, runtimes });
            if (!runtimeData.platforms.find(p => p.configs.length > 0)) {
                const res = yield ui_components_1.RequestErrors.noMetadataError('runtime', `run file as pipeline.`);
                if (res.button.label.includes(PipelineService_1.RUNTIMES_SCHEMASPACE)) {
                    // Open the runtimes widget
                    utils_1.default.getLabShell(document).activateById(`elyra-metadata:${PipelineService_1.RUNTIMES_SCHEMASPACE}`);
                }
                return;
            }
            let dependencyFileExtension = coreutils_1.PathExt.extname(context.path);
            if (dependencyFileExtension === '.ipynb') {
                dependencyFileExtension = '.py';
            }
            const dialogOptions = {
                title: 'Run file as pipeline',
                body: formDialogWidget_1.formDialogWidget(jsx_runtime_1.jsx(FileSubmissionDialog_1.FileSubmissionDialog, { env: env, dependencyFileExtension: dependencyFileExtension, images: images, runtimeData: runtimeData }, void 0)),
                buttons: [apputils_1.Dialog.cancelButton(), apputils_1.Dialog.okButton()]
            };
            const dialogResult = yield ui_components_1.showFormDialog(dialogOptions);
            if (dialogResult.value == null) {
                // When Cancel is clicked on the dialog, just return
                return;
            }
            const _b = dialogResult.value, { runtime_config, framework, cpu, gpu, memory, dependency_include, dependencies } = _b, envObject = __rest(_b, ["runtime_config", "framework", "cpu", "gpu", "memory", "dependency_include", "dependencies"]);
            const configDetails = runtime_utils_1.getConfigDetails(runtimeData, runtime_config);
            // prepare notebook submission details
            const pipeline = utils_1.default.generateSingleFilePipeline(context.path, configDetails, framework, dependency_include ? dependencies.split(',') : undefined, envObject, cpu, gpu, memory);
            PipelineService_1.PipelineService.submitPipeline(pipeline, (_a = configDetails === null || configDetails === void 0 ? void 0 : configDetails.platform.displayName) !== null && _a !== void 0 ? _a : '').catch(error => ui_components_1.RequestErrors.serverError(error));
        });
    }
    createNew(editor) {
        // Create the toolbar button
        const submitFileButton = new apputils_1.ToolbarButton({
            label: 'Run as Pipeline',
            onClick: () => this.showWidget(editor),
            tooltip: 'Run file as batch'
        });
        // Add the toolbar button to the notebook
        editor.toolbar.insertItem(10, 'submitFile', submitFileButton);
        // The ToolbarButton class implements `IDisposable`, so the
        // button *is* the extension for the purposes of this method.
        return submitFileButton;
    }
}
exports.SubmitFileButtonExtension = SubmitFileButtonExtension;
//# sourceMappingURL=SubmitFileButtonExtension.js.map